@@ -1,5 +1,5 @@
 """Top-level package for Ansible Events."""
 
 __author__ = """Ben Thomasson"""
-__email__ = 'ben.thomasson@gmail.com'
-__version__ = '0.1.2'
+__email__ = "ben.thomasson@gmail.com"
+__version__ = "__version__ = '0.5.1'"
